Skip to main contentCrate geam_json
Source - Component
- The statically composed provider component for the official Gleam JSON package.
- GleamJsonProfile
- The default profile for composing the official standard-library and JSON providers.
- GleamJsonProfileStores
- External stores for the default combined standard-library and JSON profile.
- GleamJsonRunState
- Caller-owned run state for the default combined standard-library and JSON profile.
- GleamJsonStores
- External value stores used by the official Gleam JSON provider.
- GleamJsonHostProfile
- A host profile that composes the official Gleam JSON and standard-library components.
- host_providers
- Registers the Rust provider for the official Gleam JSON package.